%global compat_version 1.2.0

Name: libtalloc
Version: 2.0.7
Release: 2%{?dist}
Group: System Environment/Daemons
Summary: A hierarchical memory allocator
License: LGPLv3+
URL: http://talloc.samba.org/
Source0: http://samba.org/ftp/talloc/talloc-%{version}.tar.gz

# For compatibility with samba3x, we will rebuild the vesion of
# libtalloc.so.1 from the samba3x sources.
# The tarball is created with generate-talloc1-tarball.sh
# The original samba source tarball is:
# http://ftp.samba.org/pub/samba/old-versions/samba-3.3.12.tar.gz
Source1: generate-talloc-compat-tarball.sh
Source2: libtalloc-%{compat_version}.tar.gz
Patch1001: 0001-build-added-autoconf-disable-silent-rules-option.patch
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

BuildRequires: autoconf
BuildRequires: libxslt
BuildRequires: docbook-style-xsl
BuildRequires: doxygen

%description
A library that implements a hierarchical allocator with destructors.

%package devel
Group: Development/Libraries
Summary: Developer tools for the Talloc library
Requires: libtalloc = %{version}-%{release}

%description devel
Header files needed to develop programs that link against the Talloc library.

%package compat1
Group: Development/Libraries
Summary: Talloc library backwards-compatibility

%description compat1
Backwards-compatible library for applications relying on the talloc 1.x
ABI.

%prep
%setup -q -n talloc-%{version}

%patch1001 -p1

%setup -q -T -D -b 2 -n libtalloc-%{compat_version}


%build
cd $RPM_BUILD_DIR/talloc-%{version}
%configure --disable-rpath \
           --disable-rpath-install \
           --bundled-libraries=NONE \
           --builtin-libraries=replace \
           --disable-silent-rules \
           --disable-python
make %{?_smp_mflags} V=1
doxygen doxy.config

cd $RPM_BUILD_DIR/libtalloc-%{compat_version}/talloc
./autogen.sh
%configure
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT

# Compatibility library
cd $RPM_BUILD_DIR/libtalloc-%{compat_version}/talloc
make install DESTDIR=$RPM_BUILD_ROOT
ln -s libtalloc.so.%{compat_version} $RPM_BUILD_ROOT%{_libdir}/libtalloc.so.1

# Main library
# Some files installed by the compatibility library will be overwritten
# This is intentional
cd $RPM_BUILD_DIR/talloc-%{version}
make install DESTDIR=$RPM_BUILD_ROOT

rm -f $RPM_BUILD_ROOT%{_libdir}/libtalloc.a
rm -f $RPM_BUILD_ROOT/usr/share/swig/*/talloc.i

# Shared libraries need to be marked executable for
# rpmbuild to strip them and include them in debuginfo
find $RPM_BUILD_ROOT -name "*.so*" -exec chmod -c +x {} \;
ls -lR $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%{_libdir}/libtalloc.so.2
%{_libdir}/libtalloc.so.%{version}

%files devel
%defattr(-,root,root,-)
%{_includedir}/talloc.h
%{_libdir}/libtalloc.so
%{_libdir}/pkgconfig/talloc.pc
%{_mandir}/man3/talloc.3.gz

%files compat1
%defattr(-,root,root,-)
%{_libdir}/libtalloc.so.1
%{_libdir}/libtalloc.so.1.2.0

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post compat1 -p /sbin/ldconfig
%postun compat1 -p /sbin/ldconfig

%changelog
* Thu Sep 13 2012 Jakub Hrozek <jhrozek@redhat.com> - 2.0.7-2
- Mark libraries as executable so that they are stripped and included
  in the -debuginfo
- Resolves: rhbz#855862 - Rebase libtalloc to version 2.0.7 to pick
                          the latest bug fixes

* Thu Sep 13 2012 Jakub Hrozek <jhrozek@redhat.com> - 2.0.7-1
- Rebase to 2.0.7
- Resolves: rhbz#855862 - Rebase libtalloc to version 2.0.7 to pick
                          the latest bug fixes

* Tue Jul 31 2012 Stephen Gallagher <sgallagh@redhat.com> - 2.0.1-13
- Run 'make test' during RPM build
- Resolves: rhbz#837853 - talloc doesn't ensure that the sibling linked list
                          remains valid during a free

* Fri Jul 13 2012 Stephen Gallagher <sgallagh@redhat.com> - 2.0.1-12
- Fix link to samba version
- Resolves: rhbz#839615

* Thu Oct 14 2010 Stephen Gallagher <sgallagh@redhat.com> - 2.0.1-11
- Resolves: rhbz#643038 - libtalloc needs to support the older library for
-                         backward compatibility

* Thu Aug 05 2010 Stephen Gallagher <sgallagh@redhat.com> - 2.0.1-10
- Fixes from package review

* Thu Aug 05 2010 Stephen Gallagher <sgallagh@redhat.com> - 2.0.1-8
- Initial release for RHEL 5
- Stop building compatibility libraries

* Mon Jun 14 2010 Stephen Gallagher <sgallagh@redhat.com> - 2.0.1-7
- Rebuild libtalloc from the samba3x sources
- Remove Conflicts: samba3x

* Thu May 27 2010 Stephen Gallagher <sgallagh@redhat.com> - 2.0.1-3
- Mark libtalloc as conflicting with samba3x
- The custom version of libtalloc required by samba3x is custom and
- incompatible with the compat lib.

* Mon Mar 29 2010 Stephen Gallagher <sgallagh@redhat.com> - 2.0.1-2
- Re-add the compat lib. We need it for compatibility with samba3x

* Tue Dec 15 2009 Simo Sorce <ssorce@redhat.com> - 2.0.1-1
- New version from upstream
- Also stop building the compat lib, it is not necessary anymore

* Tue Sep  8 2009 Simo Sorce <ssorce@redhat.com> - 2.0.0-0
- New version from upstream.
- Build also sover 1 compat library to ease packages migration

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jun 17 2009 Simo Sorce <ssorce@redhat.com> - 1.3.1-1
- Original tarballs had a screw-up, rebuild with new fixed tarballs from
  upstream.

* Tue Jun 16 2009 Simo Sorce <ssorce@redhat.com> - 1.3.1-0
- New Upstream release.

* Wed May 6 2009 Simo Sorce <ssorce@redhat.com> - 1.3.0-0
- First public independent release from upstream
